#!/bin/bash
#
# Copyright (C) 2019 OX Software GmbH
# 
# This file is part of OX Automation.
#
# OX Automation is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# OX Automation is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
# See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with OX Automation. If not, see <http://www.gnu.org/licenses/>.
#
#
# Authors:
# Benedikt Kroening <benedikt.kroening@open-xchange.com>
#
set -e
SCRIPT_DIR="$( cd "$(dirname "$0")" ; pwd -P)"

# sourcing some commonly used functions and executing basic checks
source ${SCRIPT_DIR}/../lib/common.bash
checkRootPrivileges
detectDistribution

## Help text
show_usage() {
echo -n "
  $0 [OPTIONS]


"
}

### reading config from command line; overriding defaults
POSITIONAL=()
while [[ $# -gt 0 ]]
do
key="$1"

case $key in
    -h|--help)
    show_usage
    exit 0
    shift
    ;;
    --debug)
    echo "WARNING: Debug flag set (--debug)"
    set -x
    shift
    ;;
    --mail-host)
    echo "Using $2 as mail backend ..."
    OX_MAIL_HOST="$2"
    shift
    shift
    ;;
    --mail-domain)
    echo "Using $2 as mail domain ..."
    OX_MAIL_DOMAIN="$2"
    shift
    shift
    ;;

    *)    # unknown option
    POSITIONAL+=("$1") # save it in an array for later
    shift 
    ;;
esac
done
set -- "${POSITIONAL[@]}" # restore positional parameters

echo "Executing init scripts located at ${SCRIPT_DIR}/middleware/: "
ls -lah ${SCRIPT_DIR}/middleware/

echo "Using following configuration:"
printenv | grep "^OX_"

echo "==============================="
sleep 5
# loop through all sh files in /opt/open-xchange/docker/init.d
for i in ${SCRIPT_DIR}/middleware/*_*.sh; do
    echo "## Executing config script: $i"
    bash "$i"
done

echo "$(date)" >> /opt/open-xchange/etc/99-init-middleware-done