
#!/bin/bash
#
# Copyright (C) 2019 OX Software GmbH
# 
# This file is part of OX Automation.
#
# OX Automation is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# OX Automation is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
# See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with OX Automation. If not, see <http://www.gnu.org/licenses/>.
#
#
# Authors:
# Benedikt Kroening <benedikt.kroening@open-xchange.com>
#

set -e
SCRIPT_DIR="$( cd "$(dirname "$0")" ; pwd -P)"
# sourcing some commonly used functions and executing basic checks
source ${SCRIPT_DIR}/../lib/common.bash
source ${SCRIPT_DIR}/../lib/setup.bash
checkRootPrivileges
detectDistribution

## Help text
show_usage() {
echo -n "
  $0 [OPTIONS]
  
    --enable
    --disable
    --restart
    -k | --key <value>

"
}


### reading config from command line; overriding defaults
POSITIONAL=()
while [[ $# -gt 0 ]]
do
key="$1"

case $key in
    -h|--help)
    show_usage
    exit 0
    shift
    ;;
    --debug)
    echo "WARNING: Debug flag set (--debug)"
    set -x
    shift
    ;;
    --enable)
    FEATURE_ENABLE=true
    shift
    ;;
    --disable)
    FEATURE_ENABLE=false
    shift
    ;;
    # -k|--key)
    # value="$2"
    # shift
    # shift
    # ;;
    --restart)
    RESTART_OX=true
    shift
    ;;
    *)    # unknown option
    POSITIONAL+=("$1") # save it in an array for later
    shift 
    ;;
esac
done
set -- "${POSITIONAL[@]}" # restore positional parameters


if [[ "${FEATURE_ENABLE}" = true  ]]; then
  echo "Enabling FEATURE ... "
  installPackagesRetry "open-xchange-multifactor"

  if [[ -f /usr/share/doc/open-xchange-multifactor/properties/multifactor.properties ]]; then
    echo "Copying over default multifactor.properties file ..."
    /bin/cp -vf /usr/share/doc/open-xchange-multifactor/properties/multifactor.properties /opt/open-xchange/etc/multifactor.properties
  fi

  setOXProperty com.openexchange.capability.multifactor "true" /opt/open-xchange/etc/multifactor.properties
  setOXProperty com.openexchange.multifactor.u2f.enabled "true" /opt/open-xchange/etc/multifactor.properties
  setOXProperty com.openexchange.multifactor.u2f.appid "" /opt/open-xchange/etc/multifactor.properties
  setOXProperty com.openexchange.multifactor.totp.enabled "true" /opt/open-xchange/etc/multifactor.properties

  echo "Reloading ox config ..."
  /opt/open-xchange/sbin/reloadconfiguration
elif [[ "${FEATURE_ENABLE}" = false  ]]; then
  setOXProperty com.openexchange.capability.multifactor "false" /opt/open-xchange/etc/multifactor.properties
  # do something to disable it
    echo "Reloading ox config ..."
  /opt/open-xchange/sbin/reloadconfiguration
fi

if [[ "${RESTART_OX}" = true  ]]; then
  restartService open-xchange
fi